import argparse
import logging
import sys

from aat_wrest.observation_wrester import WrestObservationMetadata
from aat_wrest.metadata_wrester import WrestWorkflowMetadata
from aat_wrest.utilities import MDDBConnector

"""
AAT Wrest extract information from the NRAO Archive metadata database
"""

logger = logging.getLogger("aat_wrest")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


def parser() -> argparse.ArgumentParser:
    arg_parser = argparse.ArgumentParser(
        description="Workspaces-to-Archive Metadata Exchange",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    arg_parser.add_argument(
        "-sc",
        "--stdcals",
        nargs=1,
        action="store",
        required=False,
        help="Find workflow metadata for standard calibrations with provided product locator",
    )
    arg_parser.add_argument(
        "-si",
        "--stdimg",
        nargs=1,
        action="store",
        required=False,
        help="Find workflow metadata for standard CMS imaging with provided SDM id",
    )
    arg_parser.add_argument(
        "-r",
        "--restore",
        nargs="+",
        default=[],
        required=False,
        help="Find workflow metadata for Restores with provided EB product locator and Cal product locator",
    )
    arg_parser.add_argument(
        "-obs",
        "--observation",
        nargs=1,
        action="store",
        required=False,
        help="Find display metadata for observations by SDM id",
    )
    arg_parser.add_argument(
        "-aux",
        "--auxiliary-ingestion",
        nargs=1,
        action="store",
        required=False,
        help="Find auxiliary imaging metadata for ingestion",
    )
    arg_parser.add_argument(
        "--carta",
        nargs=1,
        action="store",
        required=False,
        help="Find image names for single image carta requests",
    )
    return arg_parser


def determine_wrester(connection: MDDBConnector, args: argparse.Namespace):
    if args.stdcals:
        data = WrestWorkflowMetadata(connection, spl=args.stdcals[0]).wrest_standard_cal_info()
    elif args.stdimg:
        data = WrestWorkflowMetadata(connection, sdm_id=args.stdimg[0]).wrest_standard_image_info()
    elif args.restore:
        data = WrestWorkflowMetadata(connection, spl=args.restore).wrest_restore_info()
    elif args.carta:
        data = WrestWorkflowMetadata(connection, spl=args.carta).wrest_image_name()
    elif args.observation:
        data = WrestObservationMetadata(
            connection, sdm_id=args.observation[0]
        ).wrest_observation_info()
    elif args.auxiliary_ingestion:
        if str(args.auxiliary_ingestion[0]).startswith("uid"):
            data = WrestWorkflowMetadata(
                connection, spl=args.auxiliary_ingestion[0]
            ).wrest_aux_imaging_info()
        else:
            data = WrestWorkflowMetadata(
                connection, sdm_id=args.auxiliary_ingestion[0]
            ).wrest_aux_imaging_info()
    else:
        data = None

    print(data)


def main():
    args = parser().parse_args()
    connection = MDDBConnector()

    determine_wrester(connection, args)
